# Makerdiary nRF52840 M.2 Developer Kit

The devkit is a versatile IoT prototyping platform,
including the nRF52840 M.2 Module and M.2 Dock. You can use the developer kit
to prototype your IoT products and then scale to production faster using the
nRF52840 M.2 Module combined with your custom PCB hardware.

Refer to https://github.com/makerdiary/nrf52840-m2-devkit for more details.
